import React, { ButtonHTMLAttributes, ReactNode, forwardRef } from 'react';
import Link from 'next/link';
import styles from '@/styles/common/Button.module.scss';

export type ButtonVariant = 'primary' | 'secondary' | 'outline' | 'text' | 'danger' | 'success';
export type ButtonSize = 'xs' | 'sm' | 'md' | 'lg' | 'xl';

export interface ButtonProps extends ButtonHTMLAttributes<HTMLButtonElement> {
  children: ReactNode;
  variant?: ButtonVariant;
  size?: ButtonSize;
  href?: string;
  fullWidth?: boolean;
  icon?: ReactNode;
  iconPosition?: 'left' | 'right';
  loading?: boolean;
  disabled?: boolean;
  className?: string;
  ariaLabel?: string;
  ariaExpanded?: boolean;
  ariaControls?: string;
  external?: boolean;
  testId?: string;
}

const Button = forwardRef<HTMLButtonElement, ButtonProps>(({
  children,
  variant = 'primary',
  size = 'md',
  href,
  fullWidth = false,
  icon = null,
  iconPosition = 'left',
  loading = false,
  disabled = false,
  className = '',
  ariaLabel,
  ariaExpanded,
  ariaControls,
  external = false,
  type = 'button',
  testId,
  ...props
}, ref) => {
  const buttonClasses = `
    ${styles.button} 
    ${styles[`button--${variant}`]} 
    ${styles[`button--${size}`]}
    ${fullWidth ? styles['button--full'] : ''}
    ${disabled || loading ? styles['button--disabled'] : ''}
    ${icon ? styles['button--with-icon'] : ''}
    ${className}
  `;
  
  const content = (
    <>
      {loading && (
        <span className={styles.buttonLoader} aria-hidden="true">
          <span className={styles.loaderCircle} />
        </span>
      )}
      
      {icon && iconPosition === 'left' && !loading && (
        <span className={styles.buttonIcon} aria-hidden="true">
          {icon}
        </span>
      )}
      
      <span className={styles.buttonText}>{children}</span>
      
      {icon && iconPosition === 'right' && !loading && (
        <span className={styles.buttonIcon} aria-hidden="true">
          {icon}
        </span>
      )}
    </>
  );
  
  // ARIA attributes
  const ariaProps = {
    'aria-disabled': disabled || loading || undefined,
    'aria-label': ariaLabel,
    'aria-expanded': ariaExpanded,
    'aria-controls': ariaControls,
  };
  
  // For links
  if (href && !disabled && !loading) {
    const linkProps = external 
      ? { target: '_blank', rel: 'noopener noreferrer' } 
      : {};
    
    return (
      <Link
        href={href}
        className={buttonClasses}
        {...linkProps}
        {...ariaProps}
        data-testid={testId}
      >
        {content}
      </Link>
    );
  }
  
  // For buttons
  return (
    <button
      type={type}
      className={buttonClasses}
      disabled={disabled || loading}
      ref={ref}
      {...ariaProps}
      {...props}
      data-testid={testId}
    >
      {content}
    </button>
  );
});

Button.displayName = 'Button';

export default Button;